@@ -8,6 +8,8 @@ from functools import partial
 import numpy as np
 import pytest
 
+import pandas.util._test_decorators as td
+
 import pandas as pd
 from pandas import (
     DataFrame,
@@ -42,9 +44,16 @@ def test_agg_api():
     def peak_to_peak(arr):
         return arr.max() - arr.min()
 
-    expected = grouped.agg([peak_to_peak])
+    with tm.assert_produces_warning(
+        FutureWarning, match="Dropping invalid", check_stacklevel=False
+    ):
+        expected = grouped.agg([peak_to_peak])
     expected.columns = ["data1", "data2"]
-    result = grouped.agg(peak_to_peak)
+
+    with tm.assert_produces_warning(
+        FutureWarning, match="Dropping invalid", check_stacklevel=False
+    ):
+        result = grouped.agg(peak_to_peak)
     tm.assert_frame_equal(result, expected)
 
 
@@ -130,11 +139,11 @@ def test_agg_dict_parameter_cast_result_dtypes():
     tm.assert_series_equal(grouped.time.agg("last"), exp["time"])
 
     # count
-    exp = pd.Series([2, 2, 2, 2], index=Index(list("ABCD"), name="class"), name="time")
+    exp = Series([2, 2, 2, 2], index=Index(list("ABCD"), name="class"), name="time")
     tm.assert_series_equal(grouped.time.agg(len), exp)
     tm.assert_series_equal(grouped.time.size(), exp)
 
-    exp = pd.Series([0, 1, 1, 2], index=Index(list("ABCD"), name="class"), name="time")
+    exp = Series([0, 1, 1, 2], index=Index(list("ABCD"), name="class"), name="time")
     tm.assert_series_equal(grouped.time.count(), exp)
 
 
@@ -143,7 +152,7 @@ def test_agg_cast_results_dtypes():
     # xref #11444
     u = [dt.datetime(2015, x + 1, 1) for x in range(12)]
     v = list("aaabbbbbbccd")
-    df = pd.DataFrame({"X": v, "Y": u})
+    df = DataFrame({"X": v, "Y": u})
 
     result = df.groupby("X")["Y"].agg(len)
     expected = df.groupby("X")["Y"].count()
@@ -209,14 +218,14 @@ def test_aggregate_api_consistency():
     expected = pd.concat([c_mean, c_sum, d_mean, d_sum], axis=1)
     expected.columns = MultiIndex.from_product([["C", "D"], ["mean", "sum"]])
 
-    msg = r"nested renamer is not supported"
-    with pytest.raises(SpecificationError, match=msg):
+    msg = r"Column\(s\) \['r', 'r2'\] do not exist"
+    with pytest.raises(KeyError, match=msg):
         grouped[["D", "C"]].agg({"r": np.sum, "r2": np.mean})
 
 
 def test_agg_dict_renaming_deprecation():
     # 15931
-    df = pd.DataFrame({"A": [1, 1, 1, 2, 2], "B": range(5), "C": range(5)})
+    df = DataFrame({"A": [1, 1, 1, 2, 2], "B": range(5), "C": range(5)})
 
     msg = r"nested renamer is not supported"
     with pytest.raises(SpecificationError, match=msg):
@@ -224,9 +233,11 @@ def test_agg_dict_renaming_deprecation():
             {"B": {"foo": ["sum", "max"]}, "C": {"bar": ["count", "min"]}}
         )
 
-    with pytest.raises(SpecificationError, match=msg):
+    msg = r"Column\(s\) \['ma'\] do not exist"
+    with pytest.raises(KeyError, match=msg):
         df.groupby("A")[["B", "C"]].agg({"ma": "max"})
 
+    msg = r"nested renamer is not supported"
     with pytest.raises(SpecificationError, match=msg):
         df.groupby("A").B.agg({"foo": "count"})
 
@@ -290,7 +301,8 @@ def test_agg_item_by_item_raise_typeerror():
         raise TypeError("test")
 
     with pytest.raises(TypeError, match="test"):
-        df.groupby(0).agg(raiseException)
+        with tm.assert_produces_warning(FutureWarning, match="Dropping invalid"):
+            df.groupby(0).agg(raiseException)
 
 
 def test_series_agg_multikey():
@@ -410,9 +422,10 @@ def test_agg_callables():
         tm.assert_frame_equal(result, expected)
 
 
+@td.skip_array_manager_not_yet_implemented  # TODO(ArrayManager) columns with ndarrays
 def test_agg_over_numpy_arrays():
     # GH 3788
-    df = pd.DataFrame(
+    df = DataFrame(
         [
             [1, np.array([10, 20, 30])],
             [1, np.array([40, 50, 60])],
@@ -420,49 +433,59 @@ def test_agg_over_numpy_arrays():
         ],
         columns=["category", "arraydata"],
     )
-    result = df.groupby("category").agg(sum)
+    gb = df.groupby("category")
 
     expected_data = [[np.array([50, 70, 90])], [np.array([20, 30, 40])]]
-    expected_index = pd.Index([1, 2], name="category")
+    expected_index = Index([1, 2], name="category")
     expected_column = ["arraydata"]
-    expected = pd.DataFrame(
-        expected_data, index=expected_index, columns=expected_column
-    )
+    expected = DataFrame(expected_data, index=expected_index, columns=expected_column)
 
+    alt = gb.sum(numeric_only=False)
+    tm.assert_frame_equal(alt, expected)
+
+    result = gb.agg("sum", numeric_only=False)
     tm.assert_frame_equal(result, expected)
 
+    # FIXME: the original version of this test called `gb.agg(sum)`
+    #  and that raises TypeError if `numeric_only=False` is passed
 
-def test_agg_tzaware_non_datetime_result():
+
+@pytest.mark.parametrize("as_period", [True, False])
+def test_agg_tzaware_non_datetime_result(as_period):
     # discussed in GH#29589, fixed in GH#29641, operating on tzaware values
     #  with function that is not dtype-preserving
-    dti = pd.date_range("2012-01-01", periods=4, tz="UTC")
-    df = pd.DataFrame({"a": [0, 0, 1, 1], "b": dti})
+    dti = date_range("2012-01-01", periods=4, tz="UTC")
+    if as_period:
+        dti = dti.tz_localize(None).to_period("D")
+
+    df = DataFrame({"a": [0, 0, 1, 1], "b": dti})
     gb = df.groupby("a")
 
     # Case that _does_ preserve the dtype
     result = gb["b"].agg(lambda x: x.iloc[0])
-    expected = pd.Series(dti[::2], name="b")
+    expected = Series(dti[::2], name="b")
     expected.index.name = "a"
     tm.assert_series_equal(result, expected)
 
     # Cases that do _not_ preserve the dtype
     result = gb["b"].agg(lambda x: x.iloc[0].year)
-    expected = pd.Series([2012, 2012], name="b")
+    expected = Series([2012, 2012], name="b")
     expected.index.name = "a"
     tm.assert_series_equal(result, expected)
 
     result = gb["b"].agg(lambda x: x.iloc[-1] - x.iloc[0])
-    expected = pd.Series([pd.Timedelta(days=1), pd.Timedelta(days=1)], name="b")
+    expected = Series([pd.Timedelta(days=1), pd.Timedelta(days=1)], name="b")
     expected.index.name = "a"
+    if as_period:
+        expected = Series([pd.offsets.Day(1), pd.offsets.Day(1)], name="b")
+        expected.index.name = "a"
     tm.assert_series_equal(result, expected)
 
 
 def test_agg_timezone_round_trip():
     # GH 15426
     ts = pd.Timestamp("2016-01-01 12:00:00", tz="US/Pacific")
-    df = pd.DataFrame(
-        {"a": 1, "b": [ts + dt.timedelta(minutes=nn) for nn in range(10)]}
-    )
+    df = DataFrame({"a": 1, "b": [ts + dt.timedelta(minutes=nn) for nn in range(10)]})
 
     result1 = df.groupby("a")["b"].agg(np.min).iloc[0]
     result2 = df.groupby("a")["b"].agg(lambda x: np.min(x)).iloc[0]
@@ -475,7 +498,7 @@ def test_agg_timezone_round_trip():
     dates = [
         pd.Timestamp(f"2016-01-0{i:d} 12:00:00", tz="US/Pacific") for i in range(1, 5)
     ]
-    df = pd.DataFrame({"A": ["a", "b"] * 2, "B": dates})
+    df = DataFrame({"A": ["a", "b"] * 2, "B": dates})
     grouped = df.groupby("A")
 
     ts = df["B"].iloc[0]
@@ -484,51 +507,56 @@ def test_agg_timezone_round_trip():
     assert ts == grouped.first()["B"].iloc[0]
 
     # GH#27110 applying iloc should return a DataFrame
-    assert ts == grouped.apply(lambda x: x.iloc[0]).iloc[0, 0]
+    assert ts == grouped.apply(lambda x: x.iloc[0]).iloc[0, 1]
 
     ts = df["B"].iloc[2]
     assert ts == grouped.last()["B"].iloc[0]
 
     # GH#27110 applying iloc should return a DataFrame
-    assert ts == grouped.apply(lambda x: x.iloc[-1]).iloc[0, 0]
+    assert ts == grouped.apply(lambda x: x.iloc[-1]).iloc[0, 1]
 
 
 def test_sum_uint64_overflow():
     # see gh-14758
     # Convert to uint64 and don't overflow
-    df = pd.DataFrame([[1, 2], [3, 4], [5, 6]], dtype=object)
+    df = DataFrame([[1, 2], [3, 4], [5, 6]], dtype=object)
     df = df + 9223372036854775807
 
-    index = pd.Index(
+    index = Index(
         [9223372036854775808, 9223372036854775810, 9223372036854775812], dtype=np.uint64
     )
-    expected = pd.DataFrame(
+    expected = DataFrame(
         {1: [9223372036854775809, 9223372036854775811, 9223372036854775813]},
         index=index,
     )
 
     expected.index.name = 0
-    result = df.groupby(0).sum()
+    result = df.groupby(0).sum(numeric_only=False)
     tm.assert_frame_equal(result, expected)
 
+    # out column is non-numeric, so with numeric_only=True it is dropped
+    result2 = df.groupby(0).sum(numeric_only=True)
+    expected2 = expected[[]]
+    tm.assert_frame_equal(result2, expected2)
+
 
 @pytest.mark.parametrize(
     "structure, expected",
     [
-        (tuple, pd.DataFrame({"C": {(1, 1): (1, 1, 1), (3, 4): (3, 4, 4)}})),
-        (list, pd.DataFrame({"C": {(1, 1): [1, 1, 1], (3, 4): [3, 4, 4]}})),
+        (tuple, DataFrame({"C": {(1, 1): (1, 1, 1), (3, 4): (3, 4, 4)}})),
+        (list, DataFrame({"C": {(1, 1): [1, 1, 1], (3, 4): [3, 4, 4]}})),
         (
             lambda x: tuple(x),
-            pd.DataFrame({"C": {(1, 1): (1, 1, 1), (3, 4): (3, 4, 4)}}),
+            DataFrame({"C": {(1, 1): (1, 1, 1), (3, 4): (3, 4, 4)}}),
         ),
         (
             lambda x: list(x),
-            pd.DataFrame({"C": {(1, 1): [1, 1, 1], (3, 4): [3, 4, 4]}}),
+            DataFrame({"C": {(1, 1): [1, 1, 1], (3, 4): [3, 4, 4]}}),
         ),
     ],
 )
 def test_agg_structs_dataframe(structure, expected):
-    df = pd.DataFrame(
+    df = DataFrame(
         {"A": [1, 1, 1, 3, 3, 3], "B": [1, 1, 1, 4, 4, 4], "C": [1, 1, 1, 3, 4, 4]}
     )
 
@@ -540,15 +568,15 @@ def test_agg_structs_dataframe(structure, expected):
 @pytest.mark.parametrize(
     "structure, expected",
     [
-        (tuple, pd.Series([(1, 1, 1), (3, 4, 4)], index=[1, 3], name="C")),
-        (list, pd.Series([[1, 1, 1], [3, 4, 4]], index=[1, 3], name="C")),
-        (lambda x: tuple(x), pd.Series([(1, 1, 1), (3, 4, 4)], index=[1, 3], name="C")),
-        (lambda x: list(x), pd.Series([[1, 1, 1], [3, 4, 4]], index=[1, 3], name="C")),
+        (tuple, Series([(1, 1, 1), (3, 4, 4)], index=[1, 3], name="C")),
+        (list, Series([[1, 1, 1], [3, 4, 4]], index=[1, 3], name="C")),
+        (lambda x: tuple(x), Series([(1, 1, 1), (3, 4, 4)], index=[1, 3], name="C")),
+        (lambda x: list(x), Series([[1, 1, 1], [3, 4, 4]], index=[1, 3], name="C")),
     ],
 )
 def test_agg_structs_series(structure, expected):
     # Issue #18079
-    df = pd.DataFrame(
+    df = DataFrame(
         {"A": [1, 1, 1, 3, 3, 3], "B": [1, 1, 1, 4, 4, 4], "C": [1, 1, 1, 3, 4, 4]}
     )
 
@@ -559,11 +587,11 @@ def test_agg_structs_series(structure, expected):
 
 def test_agg_category_nansum(observed):
     categories = ["a", "b", "c"]
-    df = pd.DataFrame(
+    df = DataFrame(
         {"A": pd.Categorical(["a", "a", "b"], categories=categories), "B": [1, 2, 3]}
     )
     result = df.groupby("A", observed=observed).B.agg(np.nansum)
-    expected = pd.Series(
+    expected = Series(
         [3, 3, 0],
         index=pd.CategoricalIndex(["a", "b", "c"], categories=categories, name="A"),
         name="B",
@@ -575,12 +603,10 @@ def test_agg_category_nansum(observed):
 
 def test_agg_list_like_func():
     # GH 18473
-    df = pd.DataFrame(
-        {"A": [str(x) for x in range(3)], "B": [str(x) for x in range(3)]}
-    )
+    df = DataFrame({"A": [str(x) for x in range(3)], "B": [str(x) for x in range(3)]})
     grouped = df.groupby("A", as_index=False, sort=False)
     result = grouped.agg({"B": lambda x: list(x)})
-    expected = pd.DataFrame(
+    expected = DataFrame(
         {"A": [str(x) for x in range(3)], "B": [[str(x)] for x in range(3)]}
     )
     tm.assert_frame_equal(result, expected)
@@ -588,7 +614,7 @@ def test_agg_list_like_func():
 
 def test_agg_lambda_with_timezone():
     # GH 23683
-    df = pd.DataFrame(
+    df = DataFrame(
         {
             "tag": [1, 1],
             "date": [
@@ -598,9 +624,9 @@ def test_agg_lambda_with_timezone():
         }
     )
     result = df.groupby("tag").agg({"date": lambda e: e.head(1)})
-    expected = pd.DataFrame(
+    expected = DataFrame(
         [pd.Timestamp("2018-01-01", tz="UTC")],
-        index=pd.Index([1], name="tag"),
+        index=Index([1], name="tag"),
         columns=["date"],
     )
     tm.assert_frame_equal(result, expected)
@@ -624,14 +650,18 @@ def test_groupby_agg_err_catching(err_cls):
     #  in _python_agg_general
 
     # Use a non-standard EA to make sure we don't go down ndarray paths
-    from pandas.tests.extension.decimal.array import DecimalArray, make_data, to_decimal
+    from pandas.tests.extension.decimal.array import (
+        DecimalArray,
+        make_data,
+        to_decimal,
+    )
 
     data = make_data()[:5]
-    df = pd.DataFrame(
+    df = DataFrame(
         {"id1": [0, 0, 0, 1, 1], "id2": [0, 1, 0, 1, 1], "decimals": DecimalArray(data)}
     )
 
-    expected = pd.Series(to_decimal([data[0], data[3]]))
+    expected = Series(to_decimal([data[0], data[3]]))
 
     def weird_func(x):
         # weird function that raise something other than TypeError or IndexError
