@@ -14,10 +14,22 @@ import pytest
 import pytz
 
 import pandas._libs.json as ujson
-from pandas._libs.tslib import Timestamp
-from pandas.compat import IS64, is_platform_windows
+from pandas.compat import (
+    IS64,
+    PY310,
+    is_platform_windows,
+)
 
-from pandas import DataFrame, DatetimeIndex, Index, NaT, Series, Timedelta, date_range
+from pandas import (
+    DataFrame,
+    DatetimeIndex,
+    Index,
+    NaT,
+    Series,
+    Timedelta,
+    Timestamp,
+    date_range,
+)
 import pandas._testing as tm
 
 
@@ -237,12 +249,29 @@ class TestUltraJSONTests:
             assert rounded_input == json.loads(output)
             assert rounded_input == ujson.decode(output)
 
-    @pytest.mark.parametrize("invalid_val", [20, -1, "9", None])
+    @pytest.mark.parametrize(
+        "invalid_val",
+        [
+            20,
+            -1,
+            pytest.param(
+                "9",
+                marks=pytest.mark.xfail(PY310, reason="Failing on Python 3.10 GH41940"),
+            ),
+            pytest.param(
+                None,
+                marks=pytest.mark.xfail(PY310, reason="Failing on Python 3.10 GH41940"),
+            ),
+        ],
+    )
     def test_invalid_double_precision(self, invalid_val):
         double_input = 30.12345678901234567890
         expected_exception = ValueError if isinstance(invalid_val, int) else TypeError
-
-        with pytest.raises(expected_exception):
+        msg = (
+            r"Invalid value '.*' for option 'double_precision', max is '15'|"
+            r"an integer is required \(got type "
+        )
+        with pytest.raises(expected_exception, match=msg):
             ujson.encode(double_input, double_precision=invalid_val)
 
     def test_encode_string_conversion2(self):
@@ -447,13 +476,13 @@ class TestUltraJSONTests:
         decoded_input.member = O2()
         decoded_input.member.member = decoded_input
 
-        with pytest.raises(OverflowError):
+        with pytest.raises(OverflowError, match="Maximum recursion level reached"):
             ujson.encode(decoded_input)
 
     def test_decode_jibberish(self):
         jibberish = "fdsa sda v9sa fdsa"
-
-        with pytest.raises(ValueError):
+        msg = "Unexpected character found when decoding 'false'"
+        with pytest.raises(ValueError, match=msg):
             ujson.decode(jibberish)
 
     @pytest.mark.parametrize(
@@ -466,12 +495,13 @@ class TestUltraJSONTests:
         ],
     )
     def test_decode_broken_json(self, broken_json):
-        with pytest.raises(ValueError):
+        msg = "Expected object or value"
+        with pytest.raises(ValueError, match=msg):
             ujson.decode(broken_json)
 
     @pytest.mark.parametrize("too_big_char", ["[", "{"])
     def test_decode_depth_too_big(self, too_big_char):
-        with pytest.raises(ValueError):
+        with pytest.raises(ValueError, match="Reached object decoding depth limit"):
             ujson.decode(too_big_char * (1024 * 1024))
 
     @pytest.mark.parametrize(
@@ -485,13 +515,27 @@ class TestUltraJSONTests:
         ],
     )
     def test_decode_bad_string(self, bad_string):
-        with pytest.raises(ValueError):
+        msg = (
+            "Unexpected character found when decoding|"
+            "Unmatched ''\"' when when decoding 'string'"
+        )
+        with pytest.raises(ValueError, match=msg):
             ujson.decode(bad_string)
 
-    @pytest.mark.parametrize("broken_json", ['{{1337:""}}', '{{"key":"}', "[[[true"])
-    def test_decode_broken_json_leak(self, broken_json):
+    @pytest.mark.parametrize(
+        "broken_json, err_msg",
+        [
+            (
+                '{{1337:""}}',
+                "Key name of object must be 'string' when decoding 'object'",
+            ),
+            ('{{"key":"}', "Unmatched ''\"' when when decoding 'string'"),
+            ("[[[true", "Unexpected character found when decoding array value (2)"),
+        ],
+    )
+    def test_decode_broken_json_leak(self, broken_json, err_msg):
         for _ in range(1000):
-            with pytest.raises(ValueError):
+            with pytest.raises(ValueError, match=re.escape(err_msg)):
                 ujson.decode(broken_json)
 
     @pytest.mark.parametrize(
@@ -503,7 +547,12 @@ class TestUltraJSONTests:
         ],
     )
     def test_decode_invalid_dict(self, invalid_dict):
-        with pytest.raises(ValueError):
+        msg = (
+            "Key name of object must be 'string' when decoding 'object'|"
+            "No ':' found when decoding object value|"
+            "Expected object or value"
+        )
+        with pytest.raises(ValueError, match=msg):
             ujson.decode(invalid_dict)
 
     @pytest.mark.parametrize(
@@ -567,7 +616,7 @@ class TestUltraJSONTests:
         assert str(bigNum) == encoding
 
         # GH20599
-        with pytest.raises(ValueError):
+        with pytest.raises(ValueError, match="Value is too big"):
             assert ujson.loads(encoding) == bigNum
 
     @pytest.mark.parametrize(
@@ -789,21 +838,70 @@ class TestNumpyJSONTests:
             ujson.encode(np.array(1))
 
     @pytest.mark.parametrize(
-        "bad_input,exc_type,kwargs",
+        "bad_input,exc_type,err_msg,kwargs",
         [
-            ([{}, []], ValueError, {}),
-            ([42, None], TypeError, {}),
-            ([["a"], 42], ValueError, {}),
-            ([42, {}, "a"], TypeError, {}),
-            ([42, ["a"], 42], ValueError, {}),
-            (["a", "b", [], "c"], ValueError, {}),
-            ([{"a": "b"}], ValueError, {"labelled": True}),
-            ({"a": {"b": {"c": 42}}}, ValueError, {"labelled": True}),
-            ([{"a": 42, "b": 23}, {"c": 17}], ValueError, {"labelled": True}),
+            (
+                [{}, []],
+                ValueError,
+                r"nesting not supported for object or variable length dtypes",
+                {},
+            ),
+            (
+                [42, None],
+                TypeError,
+                r"int\(\) argument must be a string, a bytes-like object or a( real)? "
+                r"number, not 'NoneType'",
+                {},
+            ),
+            (
+                [["a"], 42],
+                ValueError,
+                r"Cannot decode multidimensional arrays with variable length elements "
+                r"to numpy",
+                {},
+            ),
+            (
+                [42, {}, "a"],
+                TypeError,
+                r"int\(\) argument must be a string, a bytes-like object or a( real)? "
+                r"number, not 'dict'",
+                {},
+            ),
+            (
+                [42, ["a"], 42],
+                ValueError,
+                r"invalid literal for int\(\) with base 10: 'a'",
+                {},
+            ),
+            (
+                ["a", "b", [], "c"],
+                ValueError,
+                r"nesting not supported for object or variable length dtypes",
+                {},
+            ),
+            (
+                [{"a": "b"}],
+                ValueError,
+                r"Cannot decode multidimensional arrays with variable length elements "
+                r"to numpy",
+                {"labelled": True},
+            ),
+            (
+                {"a": {"b": {"c": 42}}},
+                ValueError,
+                r"labels only supported up to 2 dimensions",
+                {"labelled": True},
+            ),
+            (
+                [{"a": 42, "b": 23}, {"c": 17}],
+                ValueError,
+                r"cannot reshape array of size 3 into shape \(2,1\)",
+                {"labelled": True},
+            ),
         ],
     )
-    def test_array_numpy_except(self, bad_input, exc_type, kwargs):
-        with pytest.raises(exc_type):
+    def test_array_numpy_except(self, bad_input, exc_type, err_msg, kwargs):
+        with pytest.raises(exc_type, match=err_msg):
             ujson.decode(ujson.dumps(bad_input), numpy=True, **kwargs)
 
     def test_array_numpy_labelled(self):
@@ -1010,7 +1108,7 @@ class TestPandasJSONTests:
     def test_datetime_index(self):
         date_unit = "ns"
 
-        # freq doesnt round-trip
+        # freq doesn't round-trip
         rng = DatetimeIndex(list(date_range("1/1/2000", periods=20)), freq=None)
         encoded = ujson.encode(rng, date_unit=date_unit)
 
@@ -1034,7 +1132,11 @@ class TestPandasJSONTests:
         ],
     )
     def test_decode_invalid_array(self, invalid_arr):
-        with pytest.raises(ValueError):
+        msg = (
+            "Expected object or value|Trailing data|"
+            "Unexpected character found when decoding array value"
+        )
+        with pytest.raises(ValueError, match=msg):
             ujson.decode(invalid_arr)
 
     @pytest.mark.parametrize("arr", [[], [31337]])
@@ -1049,18 +1151,18 @@ class TestPandasJSONTests:
         "too_extreme_num", ["9223372036854775808", "-90223372036854775809"]
     )
     def test_decode_too_extreme_numbers(self, too_extreme_num):
-        with pytest.raises(ValueError):
+        with pytest.raises(ValueError, match="Value is too big|Value is too small"):
             ujson.decode(too_extreme_num)
 
     def test_decode_with_trailing_whitespaces(self):
         assert {} == ujson.decode("{}\n\t ")
 
     def test_decode_with_trailing_non_whitespaces(self):
-        with pytest.raises(ValueError):
+        with pytest.raises(ValueError, match="Trailing data"):
             ujson.decode("{}\n\t a")
 
     def test_decode_array_with_big_int(self):
-        with pytest.raises(ValueError):
+        with pytest.raises(ValueError, match="Value is too big"):
             ujson.loads("[18446098363113800555]")
 
     @pytest.mark.parametrize(
