@@ -1,12 +1,25 @@
-from collections import abc, deque
+from collections import (
+    abc,
+    deque,
+)
 from decimal import Decimal
 from warnings import catch_warnings
 
 import numpy as np
 import pytest
 
+import pandas.util._test_decorators as td
+
 import pandas as pd
-from pandas import DataFrame, Index, MultiIndex, Series, concat, date_range
+from pandas import (
+    DataFrame,
+    Index,
+    MultiIndex,
+    PeriodIndex,
+    Series,
+    concat,
+    date_range,
+)
 import pandas._testing as tm
 from pandas.core.arrays import SparseArray
 from pandas.core.construction import create_series_with_explicit_dtype
@@ -14,6 +27,24 @@ from pandas.tests.extension.decimal import to_decimal
 
 
 class TestConcatenate:
+    def test_append_concat(self):
+        # GH#1815
+        d1 = date_range("12/31/1990", "12/31/1999", freq="A-DEC")
+        d2 = date_range("12/31/2000", "12/31/2009", freq="A-DEC")
+
+        s1 = Series(np.random.randn(10), d1)
+        s2 = Series(np.random.randn(10), d2)
+
+        s1 = s1.to_period()
+        s2 = s2.to_period()
+
+        # drops index
+        result = concat([s1, s2])
+        assert isinstance(result.index, PeriodIndex)
+        assert result.index[0] == s1.index[0]
+
+    # TODO(ArrayManager) using block internals to verify, needs rewrite
+    @td.skip_array_manager_invalid_test
     def test_concat_copy(self):
         df = DataFrame(np.random.randn(4, 3))
         df2 = DataFrame(np.random.randint(0, 10, size=4).reshape(4, 1))
@@ -29,9 +60,9 @@ class TestConcatenate:
         result = concat([df, df2, df3], axis=1, copy=False)
 
         for b in result._mgr.blocks:
-            if b.is_float:
+            if b.dtype.kind == "f":
                 assert b.values.base is df._mgr.blocks[0].values.base
-            elif b.is_integer:
+            elif b.dtype.kind in ["i", "u"]:
                 assert b.values.base is df2._mgr.blocks[0].values.base
             elif b.is_object:
                 assert b.values.base is not None
@@ -40,9 +71,9 @@ class TestConcatenate:
         df4 = DataFrame(np.random.randn(4, 1))
         result = concat([df, df2, df3, df4], axis=1, copy=False)
         for b in result._mgr.blocks:
-            if b.is_float:
+            if b.dtype.kind == "f":
                 assert b.values.base is None
-            elif b.is_integer:
+            elif b.dtype.kind in ["i", "u"]:
                 assert b.values.base is df2._mgr.blocks[0].values.base
             elif b.is_object:
                 assert b.values.base is not None
@@ -317,6 +348,10 @@ class TestConcatenate:
         expected = concat([df, df], keys=["foo", "bar"])
         tm.assert_frame_equal(result, expected[:10])
 
+    def test_concat_no_items_raises(self):
+        with pytest.raises(ValueError, match="No objects to concatenate"):
+            concat([])
+
     def test_concat_exclude_none(self):
         df = DataFrame(np.random.randn(10, 4))
 
@@ -410,42 +445,42 @@ class TestConcatenate:
                 except KeyError as err:
                     raise IndexError from err
 
-        tm.assert_frame_equal(pd.concat(CustomIterator1(), ignore_index=True), expected)
+        tm.assert_frame_equal(concat(CustomIterator1(), ignore_index=True), expected)
 
         class CustomIterator2(abc.Iterable):
             def __iter__(self):
                 yield df1
                 yield df2
 
-        tm.assert_frame_equal(pd.concat(CustomIterator2(), ignore_index=True), expected)
+        tm.assert_frame_equal(concat(CustomIterator2(), ignore_index=True), expected)
 
     def test_concat_order(self):
         # GH 17344
         dfs = [DataFrame(index=range(3), columns=["a", 1, None])]
         dfs += [DataFrame(index=range(3), columns=[None, 1, "a"]) for i in range(100)]
 
-        result = pd.concat(dfs, sort=True).columns
+        result = concat(dfs, sort=True).columns
         expected = dfs[0].columns
         tm.assert_index_equal(result, expected)
 
     def test_concat_different_extension_dtypes_upcasts(self):
-        a = Series(pd.core.arrays.integer_array([1, 2]))
+        a = Series(pd.array([1, 2], dtype="Int64"))
         b = Series(to_decimal([1, 2]))
 
-        result = pd.concat([a, b], ignore_index=True)
+        result = concat([a, b], ignore_index=True)
         expected = Series([1, 2, Decimal(1), Decimal(2)], dtype=object)
         tm.assert_series_equal(result, expected)
 
     def test_concat_ordered_dict(self):
         # GH 21510
-        expected = pd.concat(
+        expected = concat(
             [Series(range(3)), Series(range(4))], keys=["First", "Another"]
         )
-        result = pd.concat({"First": Series(range(3)), "Another": Series(range(4))})
+        result = concat({"First": Series(range(3)), "Another": Series(range(4))})
         tm.assert_series_equal(result, expected)
 
 
-@pytest.mark.parametrize("pdt", [Series, pd.DataFrame])
+@pytest.mark.parametrize("pdt", [Series, DataFrame])
 @pytest.mark.parametrize("dt", np.sctypes["float"])
 def test_concat_no_unnecessary_upcast(dt, pdt):
     # GH 13247
@@ -456,11 +491,11 @@ def test_concat_no_unnecessary_upcast(dt, pdt):
         pdt(np.array([np.nan], dtype=dt, ndmin=dims)),
         pdt(np.array([5], dtype=dt, ndmin=dims)),
     ]
-    x = pd.concat(dfs)
+    x = concat(dfs)
     assert x.values.dtype == dt
 
 
-@pytest.mark.parametrize("pdt", [create_series_with_explicit_dtype, pd.DataFrame])
+@pytest.mark.parametrize("pdt", [create_series_with_explicit_dtype, DataFrame])
 @pytest.mark.parametrize("dt", np.sctypes["int"])
 def test_concat_will_upcast(dt, pdt):
     with catch_warnings(record=True):
@@ -470,7 +505,7 @@ def test_concat_will_upcast(dt, pdt):
             pdt(np.array([np.nan], ndmin=dims)),
             pdt(np.array([5], dtype=dt, ndmin=dims)),
         ]
-        x = pd.concat(dfs)
+        x = concat(dfs)
         assert x.values.dtype == "float64"
 
 
@@ -479,7 +514,7 @@ def test_concat_empty_and_non_empty_frame_regression():
     df1 = DataFrame({"foo": [1]})
     df2 = DataFrame({"foo": []})
     expected = DataFrame({"foo": [1.0]})
-    result = pd.concat([df1, df2])
+    result = concat([df1, df2])
     tm.assert_frame_equal(result, expected)
 
 
@@ -489,7 +524,7 @@ def test_concat_sparse():
     expected = DataFrame(data=[[0, 0], [1, 1], [2, 2]]).astype(
         pd.SparseDtype(np.int64, 0)
     )
-    result = pd.concat([a, a], axis=1)
+    result = concat([a, a], axis=1)
     tm.assert_frame_equal(result, expected)
 
 
@@ -500,7 +535,7 @@ def test_concat_dense_sparse():
     expected = Series(data=[1, None, 1], index=[0, 1, 0]).astype(
         pd.SparseDtype(np.float64, None)
     )
-    result = pd.concat([a, b], axis=0)
+    result = concat([a, b], axis=0)
     tm.assert_series_equal(result, expected)
 
 
@@ -538,11 +573,11 @@ def test_concat_frame_axis0_extension_dtypes():
     df1 = DataFrame({"a": pd.array([1, 2, 3], dtype="Int64")})
     df2 = DataFrame({"a": np.array([4, 5, 6])})
 
-    result = pd.concat([df1, df2], ignore_index=True)
+    result = concat([df1, df2], ignore_index=True)
     expected = DataFrame({"a": [1, 2, 3, 4, 5, 6]}, dtype="Int64")
     tm.assert_frame_equal(result, expected)
 
-    result = pd.concat([df2, df1], ignore_index=True)
+    result = concat([df2, df1], ignore_index=True)
     expected = DataFrame({"a": [4, 5, 6, 1, 2, 3]}, dtype="Int64")
     tm.assert_frame_equal(result, expected)
 
@@ -551,7 +586,7 @@ def test_concat_preserves_extension_int64_dtype():
     # GH 24768
     df_a = DataFrame({"a": [-1]}, dtype="Int64")
     df_b = DataFrame({"b": [1]}, dtype="Int64")
-    result = pd.concat([df_a, df_b], ignore_index=True)
+    result = concat([df_a, df_b], ignore_index=True)
     expected = DataFrame({"a": [-1, None], "b": [None, 1]}, dtype="Int64")
     tm.assert_frame_equal(result, expected)
 
@@ -592,3 +627,29 @@ def test_concat_null_object_with_dti():
         index=exp_index,
     )
     tm.assert_frame_equal(result, expected)
+
+
+def test_concat_multiindex_with_empty_rangeindex():
+    # GH#41234
+    mi = MultiIndex.from_tuples([("B", 1), ("C", 1)])
+    df1 = DataFrame([[1, 2]], columns=mi)
+    df2 = DataFrame(index=[1], columns=pd.RangeIndex(0))
+
+    result = concat([df1, df2])
+    expected = DataFrame([[1, 2], [np.nan, np.nan]], columns=mi)
+    tm.assert_frame_equal(result, expected)
+
+
+def test_concat_posargs_deprecation():
+    # https://github.com/pandas-dev/pandas/issues/41485
+    df = DataFrame([[1, 2, 3]], index=["a"])
+    df2 = DataFrame([[4, 5, 6]], index=["b"])
+
+    msg = (
+        "In a future version of pandas all arguments of concat "
+        "except for the argument 'objs' will be keyword-only"
+    )
+    with tm.assert_produces_warning(FutureWarning, match=msg):
+        result = concat([df, df2], 0)
+    expected = DataFrame([[1, 2, 3], [4, 5, 6]], index=["a", "b"])
+    tm.assert_frame_equal(result, expected)
